import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:url_launcher/url_launcher.dart';
import 'package:onairos/onairos_utils.dart'; // Ensure you import the utility class correctly

class OnairosButton extends StatelessWidget {
  final Map<String, dynamic> requestData;
  final String returnLink;
  // Hard-coded path to the Onairos logo within your package's assets
  final String logoAssetPath = 'assets/onairos_logo.png'; // Ensure this path is valid in your package

  const OnairosButton({
    Key? key,
    required this.requestData,
    required this.returnLink,
  }) : super(key: key);

  Future<void> _openOnairosOverlay() async {
    String jsonString = jsonEncode(requestData);
    String encodedData = Uri.encodeComponent(jsonString);

    // Use the utility class to build the Uri
    var url = OnairosUtils.buildOnairosUri(encodedData, returnLink);

    if (await canLaunchUrl(url)) {
      await launchUrl(url);
    } else {
      throw 'Could not launch $url';
    }
  }

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: _openOnairosOverlay,
      child: Image.asset(logoAssetPath), // Use the hard-coded asset path
      style: ElevatedButton.styleFrom(
        foregroundColor: Colors.grey, backgroundColor: Colors.white, shape: CircleBorder(),
        padding: EdgeInsets.all(10), // Splash color
      ),
    );
  }
}
